Index: bp-core-functions.php
===================================================================
--- bp-core-functions.php	(revision 5976)
+++ bp-core-functions.php	(working copy)
@@ -238,8 +238,8 @@
 	 * Are you using a BP-compatible theme?
 	 */
 
-	// Get current theme info
-	$ct = current_theme_info();
+	// Get current theme info via wp_get_theme()
+	$ct = wp_get_theme();
 
 	// The best way to remove this notice is to add a "buddypress" tag to
 	// your active theme's CSS header.
